@@ -480,11 +480,18 @@ class BlobMixin:
         return {name: deepcopy(getattr(self, name)) for name in self._blob_attr_state.keys()}
 
     def from_blob(self, blob, strict=False):
+        blob = deepcopy(blob)
         msg = ''
         extra_keys = set(blob.keys()) - set(self._blob_attr_state.keys())
         missing_keys = set(self._blob_attr_state.keys()) - set(blob.keys())
+        #TODO: I need to write tests aroud this.  This is new functionality where when not in strict
+        # node, extra blob keys just get ignored
         if extra_keys:
-            msg += f'\nBad Blob. These keys unrecognized: {list(extra_keys)}'
+            if strict:
+                msg += f'\nBad Blob. These keys unrecognized: {list(extra_keys)}'
+            else:
+                for key in extra_keys:
+                    del blob[key]
         if strict and missing_keys:
             msg += f'\nBad Blob.  These required keys not found: {list(missing_keys)}'
         if msg:
@@ -530,3 +537,22 @@ class Scaler(BlobMixin):
         self._ensure_fitted()
         xr = self.limits[0] + x * (self.limits[1] - self.limits[0])
         return xr
+
+
+def get_logger(name, level='info'):
+    import logging
+    import daiquiri
+    level_map = {
+        'debug': logging.DEBUG,
+        'info': logging.INFO,
+        'warning': logging.WARNING,
+        'error': logging.ERROR,
+        'critical': logging.CRITICAL,
+    }
+    allowed_levels = list(level_map.keys())
+    if level not in allowed_levels:
+        raise ValueError(f'level must be in {allowed_levels}')
+
+    daiquiri.setup(level=level_map[level])
+    logger = daiquiri.getLogger(name)
+    return logger
